@@ -17,6 +17,10 @@ print.compare_performance <- function(x, digits = 3, ...) {
   if ("p_Omnibus" %in% colnames(x)) {
     x$p_Omnibus <- insight::format_p(x$p_Omnibus)
   }
+  if ("BF" %in% colnames(x)) {
+    x$BF[is.na(x$BF)] <- 1
+    x$BF <- insight::format_bf(x$BF)
+  }
 
   x[] <- lapply(x, function(i) {
     if (is.numeric(i)) {
@@ -299,10 +303,22 @@ print.r2_nakagawa <- function(x, digits = 3, ...) {
 print.r2_bayes <- function(x, digits = 3, ...) {
   insight::print_color("# Bayesian R2 with Standard Error\n\n", "blue")
 
-  out <- sprintf("  Conditional R2: %.*f [%.*f]", digits, x$R2_Bayes, digits, attr(x, "SE")[["R2_Bayes"]])
+  r2_ci <- insight::format_ci(
+    attributes(x)$CI$R2_Bayes$CI_low,
+    attributes(x)$CI$R2_Bayes$CI_high,
+    ci = attributes(x)$CI$R2_Bayes$CI / 100,
+    digits = digits
+  )
+  out <- sprintf("  Conditional R2: %.*f (%s)", digits, x$R2_Bayes, r2_ci)
 
   if ("R2_Bayes_marginal" %in% names(x)) {
-    out <- paste0(c(out, sprintf("     Marginal R2: %.*f [%.*f]", digits, x$R2_Bayes_marginal, digits, attr(x, "SE")[["R2_Bayes_marginal"]])), collapse = "\n")
+    r2_marginal_ci <- insight::format_ci(
+      attributes(x)$CI$R2_Bayes_marginal$CI_low,
+      attributes(x)$CI$R2_Bayes_marginal$CI_high,
+      ci = attributes(x)$CI$R2_Bayes_marginal$CI / 100,
+      digits = digits
+    )
+    out <- paste0(c(out, sprintf("     Marginal R2: %.*f (%s)", digits, x$R2_Bayes_marginal, r2_marginal_ci)), collapse = "\n")
   }
 
   cat(out)
