@@ -7,8 +7,10 @@ if (require("testthat") && require("performance") && require("metafor")) {
     expect_null(mp$R2)
     expect_equal(mp$AIC, 28.40474, tolerance = 1e-3)
     expect_equal(mp$I2, 0.9222139, tolerance = 1e-3)
-    expect_equal(colnames(mp), c("AIC", "BIC", "I2", "H2", "TAU2", "CochransQ",
-                                 "p_CochransQ", "Omnibus", "p_Omnibus"))
+    expect_equal(colnames(mp), c(
+      "AIC", "BIC", "I2", "H2", "TAU2", "CochransQ",
+      "p_CochransQ", "Omnibus", "p_Omnibus"
+    ))
   })
 
   test_that("model_performance.rma", {
@@ -17,7 +19,9 @@ if (require("testthat") && require("performance") && require("metafor")) {
     expect_equal(mp$R2, 0.6463217, tolerance = 1e-3)
     expect_equal(mp$AIC, 24.21375, tolerance = 1e-3)
     expect_equal(mp$I2, 0.719778, tolerance = 1e-3)
-    expect_equal(colnames(mp), c("AIC", "BIC", "I2", "H2", "TAU2", "CochransQ",
-                                 "p_CochransQ", "Omnibus", "p_Omnibus", "R2"))
+    expect_equal(colnames(mp), c(
+      "AIC", "BIC", "I2", "H2", "TAU2", "CochransQ",
+      "p_CochransQ", "Omnibus", "p_Omnibus", "R2"
+    ))
   })
 }
